@@ -33,3 +33,12 @@ class WrapLineFormatter(HtmlFormatter):
     def __init__(self, **options):
         options.setdefault('linespans', 1)
         super().__init__(**options)
+
+    def _wrap_linespans(self, inner):
+        i = self.linenostart - 1
+        for t, line in inner:
+            if t:
+                i += 1
+                yield 1, '<span data-line="%d">%s</span>' % (i, line)
+            else:
+                yield 0, line
